import { EATS_FUNCTION } from "../main.js";
export declare class FunctionManager extends Map<string, EATS_FUNCTION> {
    #private;
    constructor(iterable?: Iterable<readonly [string, EATS_FUNCTION]> | null | undefined);
    /**
     * Add a function to the manager.
     * @param name - Function name.
     * @param value - Function data.
     */
    add(name: string, value: EATS_FUNCTION): this;
    /**
     * Injects a subfunction to a supported function.
     * @param target - Target function name.
     * @param name - Subfunction name.
     * @param value - Subfunction value.
     */
    inject(target: string, name: string, value: EATS_FUNCTION): void;
    /**
     * Return all function available for a supported function.
     * @param target - Target function name.
     */
    getTargettedInjections(target: string): Record<string, EATS_FUNCTION>;
    /**
     * Load all functions inside a folder.
     * @param dir - Function directory.
     */
    load(dir?: string): Promise<void>;
    /**
     * Returns an array of functions.
     * @returns {EATS_FUNCTION[]}
     */
    toArray(): EATS_FUNCTION[];
    /**
     * Return all function injections.
     */
    get injections(): Record<string, Record<string, EATS_FUNCTION>>;
}
