import { FunctionManager } from "../managers/FunctionManager.js";
import { Data, DatabaseManager } from "../main.js";
import { TypedEmitter } from "tiny-typed-emitter";
import * as F from "fastify";
export interface EATS_Events {
    error: (exception: Error) => any;
    request: (data: Data) => any;
    ready: (data: Data) => any;
}
export interface EATS_API_OPTIONS extends F.FastifyServerOptions {
    dots?: boolean;
    reverse?: boolean;
    debug?: boolean;
}
export interface EATS_ROUTE {
    method: F.HTTPMethods;
    url: string;
    code: string;
    comments?: boolean;
    reverse?: boolean;
}
export interface EATS_EVENT {
    name: keyof EATS_Events;
    code: string;
    comments?: boolean;
    reverse?: boolean;
}
export declare class API extends TypedEmitter<EATS_Events> {
    app: F.FastifyInstance;
    functions: FunctionManager;
    private interpreter;
    options: EATS_API_OPTIONS;
    db: DatabaseManager;
    constructor(ops: EATS_API_OPTIONS);
    /**
     * Adds a route to the API.
     */
    route(data: EATS_ROUTE): void;
    /**
     * Run code when events gets emitted.
     */
    event(data: EATS_EVENT): void;
    /**
     * Loads routes, events and functions using this method.
     */
    load(dir: string): Promise<void>;
    private isEvent;
    private isRoute;
    private isFunction;
    connect(options: F.FastifyListenOptions): Promise<void>;
}
